
import datetime
import uuid

from nsj_rest_lib.decorator.dto import DTO
from nsj_rest_lib.descriptor.dto_field import DTOField
from nsj_rest_lib.descriptor.dto_field_validators import DTOFieldValidators
from nsj_rest_lib.dto.dto_base import DTOBase



# Configuracoes execucao
from nsj_integracao_api_entidades.config import (tenant_is_partition_data)

@DTO()
class TituloDTO(DTOBase):
    # Atributos da entidade
    id: uuid.UUID = DTOField(
      pk=True,
      entity_field='id',
      resume=True,
      not_null=True,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tenant: int = DTOField(
      partition_data=tenant_is_partition_data,
      resume=True,
      not_null=True,)
    sinal: int = DTOField()
    origem: int = DTOField()
    numero: str = DTOField()
    emissao: datetime.datetime = DTOField()
    vencimento: datetime.datetime = DTOField()
    situacao: int = DTOField()
    parcela: int = DTOField()
    totalparcelas: int = DTOField()
    tppessoa: int = DTOField()
    observacao: str = DTOField()
    valor: float = DTOField()
    valorbruto: float = DTOField()
    irretido: float = DTOField()
    cofinsretido: float = DTOField()
    pisretido: float = DTOField()
    csllretido: float = DTOField()
    inssretido: float = DTOField()
    issretido: float = DTOField()
    desconto: float = DTOField()
    juros: float = DTOField()
    multa: float = DTOField()
    taxabancaria: float = DTOField()
    despesasbancarias: float = DTOField()
    anotacao: str = DTOField()
    id_docfis: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_estabelecimento: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_pessoa: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_darf: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_gnre: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_gps: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_icmsiss: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_outdoc: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    previsaovencimento: datetime.datetime = DTOField()
    percentualdesconto: float = DTOField()
    datalimitedesconto: datetime.datetime = DTOField()
    percentualmulta: float = DTOField()
    datainiciomulta: datetime.datetime = DTOField()
    percentualjurosdiario: float = DTOField()
    codigocontabil: str = DTOField()
    parcelapedidovenda: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    nossonumero: str = DTOField()
    linhadigitavel: str = DTOField()
    codigobarras: str = DTOField()
    conta: uuid.UUID = DTOField(
      default_value=uuid.uuid4,
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    previsaoreceber: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    aliquotapis: float = DTOField()
    aliquotacofins: float = DTOField()
    aliquotacsll: float = DTOField()
    aliquotair: float = DTOField()
    layoutcobranca: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    documentorateado: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    rps: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    situacaotexto: str = DTOField()
    origemtexto: str = DTOField()
    emissaotexto: str = DTOField()
    vencimentotexto: str = DTOField()
    valorbrutotexto: str = DTOField()
    emissaoanomes: str = DTOField()
    emissaodia: str = DTOField()
    vencimentoanomes: str = DTOField()
    vencimentodia: str = DTOField()
    formapagamento: int = DTOField()
    vezescartao: int = DTOField()
    valortarifacartao: float = DTOField()
    autorizacaocartao: str = DTOField()
    formapagamentotexto: str = DTOField()
    documentocartao: str = DTOField()
    numeroparcelacartao: int = DTOField()
    aliquotaiss: float = DTOField()
    pedidovenda: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    informacaocartao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    valorparcelacartao: float = DTOField()
    previsaopagar: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    numeronota: str = DTOField()
    tipopagamento: int = DTOField()
    layoutpagamento: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    dataagendamento: datetime.datetime = DTOField()
    modelodocumentofiscal: int = DTOField()
    seriedocumentofiscal: str = DTOField()
    subseriedocumentofiscal: str = DTOField()
    tipocontabilizacao: int = DTOField()
    identificadorbancario: int = DTOField()
    finalidadedocbradesco: str = DTOField()
    tipodecontabradesco: str = DTOField()
    id_rps: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    previsaovencimentotexto: str = DTOField()
    id_pedido: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_fatura: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_servicobanco: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_formapagamentobanco: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_finalidadepagamentobanco: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_tipocontapagamentobanco: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_servicons: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_formapagamentons: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_finalidadepagamentons: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_tipocontapagamentons: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    lastupdate: datetime.datetime = DTOField()
    id_bempatrimonial: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    codigodocedenteboleto: str = DTOField()
    numerodocumentoboleto: str = DTOField()
    especieboleto: str = DTOField()
    aceiteboleto: bool = DTOField()
    dataprocessamentoboleto: datetime.datetime = DTOField()
    usobancoboleto: str = DTOField()
    carteiraboleto: str = DTOField()
    datacompetenciatributos: datetime.datetime = DTOField()
    codigodareceitatributos: str = DTOField()
    numerodereferenciadarf: str = DTOField()
    outrosacrescimos: float = DTOField()
    percentualoutrosacrescimos: float = DTOField()
    modoexibicaomulta: str = DTOField(
      default_value='P',)
    modoexibicaojuros: str = DTOField(
      default_value='P',)
    modoexibicaooutros: str = DTOField(
      default_value='V',)
    modoexibicaocodigobarras: str = DTOField(
      default_value='C',)
    valorreceitabrutaacumuladadarfsimples: float = DTOField()
    percreceitabrutaacumuladadarfsimples: float = DTOField()
    numerodeclaracaogare: str = DTOField()
    numeroetiquetagare: str = DTOField()
    numerodaparcelagare: str = DTOField()
    codigorenavam: str = DTOField()
    unidadefederacaoipva: str = DTOField()
    codigomunicipioipva: str = DTOField()
    placaveiculoipva: str = DTOField()
    opcaodepagamentoipva: str = DTOField()
    opcaoretiradacrlv: str = DTOField()
    identificadorfgts: str = DTOField()
    lacreconectividadesocial: str = DTOField()
    numerodocumentodarj: str = DTOField()
    dataprovisoria: bool = DTOField(
      not_null=True,)
    valorprovisorio: bool = DTOField(
      not_null=True,)
    adiantamento: bool = DTOField()
    saldoadiantamento: float = DTOField()
    debitoautomatico: bool = DTOField(
      not_null=True,)
    irretidonf: float = DTOField()
    inssretidonf: float = DTOField()
    id_contrato: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    modoexibicaodesconto: str = DTOField(
      default_value='P',)
    id_dfparcela: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_formapagamento: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_fatura_mercadoria: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_renegociacao_geradora: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_renegociacao_gerada: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_renegociacao_baixa: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    usadiscriminacao: bool = DTOField()
    wkf_estado: str = DTOField()
    wkf_data: datetime.datetime = DTOField()
    valorvariacaocambialativa: float = DTOField()
    valorvariacaocambialpassiva: float = DTOField()
    emprestimo: bool = DTOField(
      not_null=True,)
    id_contaemprestimo: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_conjunto_anexo: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    numerodocumento: str = DTOField()
    datacompetencia: datetime.datetime = DTOField()
    usuarioresponsavel: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    chavepersona: str = DTOField()
    tipoordempagamento: int = DTOField()
    id_template: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_usuario_cadastro: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    datahoracriacao: datetime.datetime = DTOField()
    dataautorizacaocartao: datetime.datetime = DTOField()
    id_prestacaodeconta: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    titulocoberturaconta: bool = DTOField()
    coberturaconta: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    documentorateadocobertura: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_documento_associado: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    contafornecedor: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    previsto: bool = DTOField()
    pagamento: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    parcelapagamento: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    importacao_hash: str = DTOField()
    contabilizado: bool = DTOField(
      not_null=True,)
    cfop_codigo: str = DTOField(
      default_value='NULL',)
    id_titulovinculo_previsao: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_previsao_vinculada: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    id_proposta: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    rps_old: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    num: str = DTOField()
    id_erp: int = DTOField()
    estorno: bool = DTOField()
    id_titulo_estorno: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    tipoestorno: int = DTOField()
    statusestorno: int = DTOField()
    id_titulo_estornado_clone: uuid.UUID = DTOField(
      strip=True,
      min=36,
      max=36,
      validator=DTOFieldValidators().validate_uuid,)
    pisestornado: float = DTOField()
    cofinsestornado: float = DTOField()
    csllestornado: float = DTOField()
    irestornado: float = DTOField()
    inssestornado: float = DTOField()
    issestornado: float = DTOField()

